@@ -2,13 +2,14 @@
 
 from docx.api import Document  # noqa
 
-__version__ = '0.7.5'
+__version__ = '0.7.6'
 
 
 # register custom Part classes with opc package reader
 
 from docx.opc.constants import CONTENT_TYPE as CT, RELATIONSHIP_TYPE as RT
-from docx.opc.package import PartFactory
+from docx.opc.part import PartFactory
+from docx.opc.parts.coreprops import CorePropertiesPart
 
 from docx.parts.document import DocumentPart
 from docx.parts.image import ImagePart
@@ -23,8 +24,12 @@ def part_class_selector(content_type, reltype):
 
 
 PartFactory.part_class_selector = part_class_selector
+PartFactory.part_type_for[CT.OPC_CORE_PROPERTIES] = CorePropertiesPart
 PartFactory.part_type_for[CT.WML_DOCUMENT_MAIN] = DocumentPart
 PartFactory.part_type_for[CT.WML_NUMBERING] = NumberingPart
 PartFactory.part_type_for[CT.WML_STYLES] = StylesPart
 
-del CT, DocumentPart, PartFactory, part_class_selector
+del (
+    CT, CorePropertiesPart, DocumentPart, NumberingPart, PartFactory,
+    StylesPart, part_class_selector
+)
