@@ -108,6 +108,14 @@ class Document(object):
             table.style = style
         return table
 
+    @property
+    def core_properties(self):
+        """
+        A |CoreProperties| object providing read/write access to the core
+        properties of this document.
+        """
+        return self._package.core_properties
+
     @property
     def inline_shapes(self):
         """
