@@ -8,6 +8,7 @@ from __future__ import absolute_import, print_function, unicode_literals
 
 import pytest
 
+from docx.enum.table import WD_TABLE_ALIGNMENT
 from docx.oxml import parse_xml
 from docx.oxml.table import CT_Tc
 from docx.shared import Inches
@@ -23,6 +24,42 @@ from .unitutil.mock import instance_mock, property_mock
 
 class DescribeTable(object):
 
+    def it_knows_its_alignment_setting(self, alignment_get_fixture):
+        table, expected_value = alignment_get_fixture
+        assert table.alignment == expected_value
+
+    def it_can_change_its_alignment_setting(self, alignment_set_fixture):
+        table, new_value, expected_xml = alignment_set_fixture
+        table.alignment = new_value
+        assert table._tbl.xml == expected_xml
+
+    def it_knows_whether_it_should_autofit(self, autofit_get_fixture):
+        table, expected_value = autofit_get_fixture
+        assert table.autofit is expected_value
+
+    def it_can_change_its_autofit_setting(self, autofit_set_fixture):
+        table, new_value, expected_xml = autofit_set_fixture
+        table.autofit = new_value
+        assert table._tbl.xml == expected_xml
+
+    def it_knows_its_table_style(self, table_style_get_fixture):
+        table, style = table_style_get_fixture
+        assert table.style == style
+
+    def it_can_apply_a_table_style_by_name(self, table_style_set_fixture):
+        table, style_name, expected_xml = table_style_set_fixture
+        table.style = style_name
+        assert table._tbl.xml == expected_xml
+
+    def it_knows_it_is_the_table_its_children_belong_to(self, table_fixture):
+        table = table_fixture
+        assert table.table is table
+
+    def it_knows_its_column_count_to_help(self, column_count_fixture):
+        table, expected_value = column_count_fixture
+        column_count = table._column_count
+        assert column_count == expected_value
+
     def it_provides_access_to_the_table_rows(self, table):
         rows = table.rows
         assert isinstance(rows, _Rows)
@@ -64,33 +101,6 @@ class DescribeTable(object):
         assert isinstance(column, _Column)
         assert column._gridCol is table._tbl.tblGrid.gridCol_lst[1]
 
-    def it_knows_its_table_style(self, table_style_get_fixture):
-        table, style = table_style_get_fixture
-        assert table.style == style
-
-    def it_can_apply_a_table_style_by_name(self, table_style_set_fixture):
-        table, style_name, expected_xml = table_style_set_fixture
-        table.style = style_name
-        assert table._tbl.xml == expected_xml
-
-    def it_knows_whether_it_should_autofit(self, autofit_get_fixture):
-        table, expected_value = autofit_get_fixture
-        assert table.autofit is expected_value
-
-    def it_can_change_its_autofit_setting(self, autofit_set_fixture):
-        table, new_value, expected_xml = autofit_set_fixture
-        table.autofit = new_value
-        assert table._tbl.xml == expected_xml
-
-    def it_knows_it_is_the_table_its_children_belong_to(self, table_fixture):
-        table = table_fixture
-        assert table.table is table
-
-    def it_knows_its_column_count_to_help(self, column_count_fixture):
-        table, expected_value = column_count_fixture
-        column_count = table._column_count
-        assert column_count == expected_value
-
     def it_provides_access_to_its_cells_to_help(self, cells_fixture):
         table, cell_count, unique_count, matches = cells_fixture
         cells = table._cells
@@ -117,6 +127,31 @@ class DescribeTable(object):
         expected_xml = _tbl_bldr(rows=2, cols=2).xml()
         return table, expected_xml
 
+    @pytest.fixture(params=[
+        ('w:tbl/w:tblPr',                    None),
+        ('w:tbl/w:tblPr/w:jc{w:val=center}', WD_TABLE_ALIGNMENT.CENTER),
+        ('w:tbl/w:tblPr/w:jc{w:val=right}',  WD_TABLE_ALIGNMENT.RIGHT),
+        ('w:tbl/w:tblPr/w:jc{w:val=left}',   WD_TABLE_ALIGNMENT.LEFT),
+    ])
+    def alignment_get_fixture(self, request):
+        tbl_cxml, expected_value = request.param
+        table = Table(element(tbl_cxml), None)
+        return table, expected_value
+
+    @pytest.fixture(params=[
+        ('w:tbl/w:tblPr', WD_TABLE_ALIGNMENT.LEFT,
+         'w:tbl/w:tblPr/w:jc{w:val=left}'),
+        ('w:tbl/w:tblPr/w:jc{w:val=left}', WD_TABLE_ALIGNMENT.RIGHT,
+         'w:tbl/w:tblPr/w:jc{w:val=right}'),
+        ('w:tbl/w:tblPr/w:jc{w:val=right}', None,
+         'w:tbl/w:tblPr'),
+    ])
+    def alignment_set_fixture(self, request):
+        tbl_cxml, new_value, expected_tbl_cxml = request.param
+        table = Table(element(tbl_cxml), None)
+        expected_xml = xml(expected_tbl_cxml)
+        return table, new_value, expected_xml
+
     @pytest.fixture(params=[
         ('w:tbl/w:tblPr',                             True),
         ('w:tbl/w:tblPr/w:tblLayout',                 True),
